/*
 * i18n.c: Internationalization
 *
 * See the README file for copyright information and how to reach the author.
 *
 * $Id: i18n.c 1.6 2006/04/22 09:30:57 kls Exp $
 */

#include "i18n.h"

const tI18nPhrase Phrases[] = {
  { "Hello",
    "Hallo",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Hei",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "!",
    "",// TODO
    "",// TODO
    "",// TODO
    "Ahoj",
  },
  { "Hello world!",
    "Hallo Welt!",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Hei maailma!",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    " !",
    "",// TODO
    "",// TODO
    "",// TODO
    "Ahoj svte!",
  },
  { "Howdy folks!",
    "Tach zusammen!",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Mit kuuluu?",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    " ?",
    "",// TODO
    "",// TODO
    "",// TODO
    "Nazdar vespolek!",
  },
  { "A friendly greeting",
    "Ein freundlicher Gru",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Ystvllisin terveisin",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    " ",
    "",// TODO
    "",// TODO
    "",// TODO
    "Ptelsk pozdrav",
  },
  { "Greeting time (s)",
    "Dauer des Grues (s)",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Tervehdysaika (s)",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    " ",
    "",// TODO
    "",// TODO
    "",// TODO
    "as pozdravu (s)",
  },
  { "Use alternate greeting",
    "Alternativen Gru verwenden",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Kyt vaihtoehtoista tervehdyst",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    " ",
    "",// TODO
    "",// TODO
    "",// TODO
    "Pout alternativn pozdrav",
  },
  { NULL }
  };
